/* -*- c++ -*- */
/*
 * Copyright 2006,2009,2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 */

#if HAVE_CONFIG_H
#include <config.h>
#endif

#include <gnuradio/constants.h>
#include <stdlib.h>
#include <boost/dll/runtime_symbol_info.hpp>
#include <boost/filesystem/path.hpp>

namespace gr {

const std::string prefix()
{
    // Use "GR_PREFIX" environment variable when specified
    const char* prefix = getenv("GR_PREFIX");
    if (prefix != NULL)
        return prefix;

    boost::filesystem::path prefix_rel_lib = "../";
    boost::filesystem::path gr_runtime_lib_path = boost::dll::this_line_location();
    // Normalize before decomposing path so result is reliable
    boost::filesystem::path prefix_path =
        gr_runtime_lib_path.lexically_normal().parent_path() / prefix_rel_lib;
    return prefix_path.lexically_normal().string();
}

const std::string sysconfdir()
{
    boost::filesystem::path sysconfdir_rel_prefix = "../etc";
    boost::filesystem::path prefix_path = prefix();
    boost::filesystem::path sysconfdir_path = prefix_path / sysconfdir_rel_prefix;

    return sysconfdir_path.lexically_normal().string();
}

const std::string prefsdir()
{
    boost::filesystem::path prefsdir_rel_prefix = "../etc/gnuradio/conf.d";
    boost::filesystem::path prefix_path = prefix();
    boost::filesystem::path prefsdir_path = prefix_path / prefsdir_rel_prefix;

    return prefsdir_path.lexically_normal().string();
}

const std::string build_date() { return "Sat, 08 May 2021 15:49:27"; }

const std::string version() { return "3.9.1.0"; }

// Return individual parts of the version
const std::string major_version() { return "3"; }

const std::string api_version() { return "9"; }

const std::string minor_version() { return "1"; }

const std::string c_compiler() { return "armh-alt-linux-gnueabi-gcc (GCC) 10.2.1 20210313 (ALT Sisyphus 10.2.1-alt3) \nCopyright (C) 2020 Free Software Foundation, Inc. \nThis is free software see the source for copying conditions.  There is NO \nwarranty not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."; }

const std::string cxx_compiler() { return "armh-alt-linux-gnueabi-g++ (GCC) 10.2.1 20210313 (ALT Sisyphus 10.2.1-alt3) \nCopyright (C) 2020 Free Software Foundation, Inc. \nThis is free software see the source for copying conditions.  There is NO \nwarranty not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."; }

const std::string compiler_flags() { return "/usr/bin/cc:::-O2 -DNDEBUG -pipe -frecord-gcc-switches -Wall -g -O2 -fomit-frame-pointer -march=armv7-a -mthumb -fvisibility=hidden -Wsign-compare -Wno-uninitialized \n/usr/bin/c++:::-O2 -DNDEBUG -pipe -frecord-gcc-switches -Wall -g -O2 -fomit-frame-pointer -march=armv7-a -mthumb -fvisibility=hidden -Wsign-compare -Wno-uninitialized"; }

const std::string build_time_enabled_components() { return "testing-support;python-support;post-install;doxygen;gnuradio-runtime;gr-ctrlport"; }
} /* namespace gr */
